\name{computeV}
\alias{computeV}

\title{Compute Covariance Matrix}

\description{
  Observations are averages over congruent rectangular plots that like
  in a lattice.  For extensive observations one needs to multiply the
  matrix by the $area^2$ where $area$ is the common area of
  each plot.

  Various different classes of covariance functions, generalised
  covariance functions and their derivatives wrt parameters
  are built into this library.  These include the Cauchy and Mat\'{e}rn
  covariance functions as well as specific sub models such as the
  Bessel$_0$, Exponential, Bessel$_1$, spline and logarithmic covariance
  functions.}

\synopsis{
computeV(info,class="ldt",params,eps=1e-8,cat.level=0)
}

\usage{
V <- computeV(info,class="matern",params=c(0.2,0.5), \dots)  ## matern
model with inverse range 0.2 and smoothness 0.5
V <- computeV(info,class="ldt",eps=1e-10,cat.level=1)  ## logarithmic model
 }

\arguments{
  \item{info}{Result of the precompute stage}
  \item{class}{The class of covariance functions,"ldt", "bess0", "exp",
    "bess1", "power", "powerNI", "matern", "spline", "cauchy".  Can also
    be used to
    compute the derivatives of the covariance matrices for specific
    models, for example "dbess0", "dexp", "dexp2", "dbess1",
    "dpowerNI".  Can also be used for any isotropic function K, simply
    define a function K in the workspace that has two arguments,
    distance and a vector of parameters.  Then call
  \code{computeV} with \code{class="special"}.}
  \item{params}{Parameters that go with a specific class of models, for
    the "matern" class it requires an inverse range parameter and a
    smoothness parameter, for example \code{params=c(1,0.5)}, this
    corresponds to the case when \code{class="exp", params=c(1)}.}
  \item{eps}{Relative Tolerance for one dimensional numerical
    integration}
  \item{cat.level}{Controls level of time output, takes values 0, 0.5, 1}
}

\author{David Clifford}

\keyword{spatial}


\eof
\name{f}
\alias{f}

\title{Density For Distance Between Two Points In Rectangles}

Density of the distance between two points distributed uniformly and
independently in two congruent rectangles that lie on a lattice}

\description{This evaluates the density for the distance between two
  points, each distribution uniformly and independently in rectangles.
  The rectangles are congruent and lie on a lattice.  Three special
  cases exist, when the two rectangles
  coincide, when the two rectangles lie on the same row
  (or column) of the lattice and when the
  two rectangles lie on different rows and columns.}

\synopsis{
  f(d,rowwidth,colwidth,ax,bx,i,j)
}

\usage{
f(d,rowwidth=1,colwidth=1,ax=0,bx=0,i=1,j=1)  ## two points in a unit square
f(d,rowwidth=1,colwidth=1,ax=1,bx=0,i=2,j=1)  ## two points in squares, squares are side by side
}

\arguments{
  \item{d}{distance}
  \item{rowwidth, colwidth}{Dimensions of the rectangle}
  \item{ax,bx}{Coordinate of the lower left corner of the second
    rectangle.  Lower left corner of the first is at the origin}
  \item{i,j}{Second rectangle lies in i-th row and j-th column of lattice.}
}

\references{
  B. Ghosh "Random distances within a rectangle and between two
  rectangles", Bulletin of the Calcutta Mathematical Society, 1951, 43, 17-24

  D. Clifford, "Computing Spatial Covariance Matrices", JCGS, to appear
}

\author{David Clifford}

\keyword{spatial}


\eof
\name{precompute}
\alias{precompute.update}
\alias{precompute}

\title{Precompute Step for Computing Covariance Matrix}

\description{For a lattice with \code{nr} rows and \code{nc} columns on
  only needs to compute $n=nr\times nc$ entries to fill the whole
  covariance matrix (of size $n \times n$).  For example, the
  diagonal entries will all be the same so one only needs to compute it
  once and know that the value needs to be placed along the diagonal.
  This algorithm figures out which entries need to be computed, and how
  to insert them into the covariance matrix.

  When an anisotropy term \code{aniso} is
  included in the direction of rows and columns it changes how distance
  is measure from $\sqrt{x^2+y^2}$ to
  $\sqrt{x^2+\alpha^2 y^2}$.  This amounts to stretching the
  lattice in the appropriate direction by a factor of $\alpha$.  We
  can update the results of the \code{precompute} stage very easily.
}

\synopsis{
precompute(nrows,ncols,rowwidth,colwidth,rowsep,colsep,cat.level=0)
}

\usage{
info <- precompute(nrows,ncols,rowwidth,colwidth,rowsep,colsep,cat.level)
info <- precompute.update(info,aniso=2)  ## geometric anisotropy update}

\arguments{
  \item{nrows,ncols}{Number of rows and columns in the lattice}
  \item{rowwidth, colwidth}{Dimensions of the rectangle}
  \item{rowsep,colsep}{Vectors of separations between rows and columns.
  Pass scalars if the separations are constant in each direction.}
  \item{cat.level}{0,0.5,1, changes the amount of output.  Output is
    limited to times for various stages of the computation}
  \item{aniso}{Value of anisotropy parameter in the direction of rows
    and columns.  Should be a positive number.}
  \item{info}{Result of the precompute stage}
}

\author{David Clifford}

\keyword{spatial}


\eof
